@@ -1,26 +1,25 @@
 /*
- MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+ 
+  $Id: common.h,v 1.18 2004/03/08 07:40:51 taku-ku Exp $;
 
- $Id: common.h,v 1.17 2003/07/01 06:43:20 taku-ku Exp $;
-
- Copyright (C) 2001-2002  Taku Kudo <taku-ku@is.aist-nara.ac.jp>
- All rights reserved.
-
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later verjsion.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
-
- You should have received a copy of the GNU Library General Public
- License along with this library; if not, write to the
- Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
-*/
+  Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
+  This is free software with ABSOLUTELY NO WARRANTY.
+  
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Lesser General Public
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
+  
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Lesser General Public License for more details.
+  
+  You should have received a copy of the GNU Lesser General Public
+  License along with this library; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*/  
 #ifndef _MECAB_COMMON_H
 #define _MECAB_COMMON_H
 
@@ -77,10 +76,10 @@ namespace MeCab {
   template <class T> inline T _min (T x, T y) { return (x < y) ? x : y; }
   template <class T> inline T _max (T x, T y) { return (x > y) ? x : y; }
 
-  static inline void itoa (int val, char *s)
+  template <class T> inline void itoa (T val, char *s)
   {
      char *t;
-     int mod;
+     T mod;
      if(val < 0) {
 	*s++ = '-';
 	val = -val;
@@ -138,7 +137,7 @@ namespace MeCab {
 
   static inline void replaceString (std::string &s, const std::string &src, const std::string &dst)
   {
-    unsigned int pos = s.find (src);
+    size_t pos = s.find (src);
     if (pos != std::string::npos) s.replace (pos, src.size(), dst);
   }
 }
