@@ -1,34 +1,33 @@
- /*
- MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+/*
+  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+ 
+  $Id: viterbisub.h,v 1.13 2004/03/08 07:40:55 taku-ku Exp $;
 
- $Id: viterbisub.h,v 1.12 2003/01/04 05:20:22 taku-ku Exp $;
-
- Copyright (C) 2001-2002  Taku Kudo <taku-ku@is.aist-nara.ac.jp>
- All rights reserved.
-
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
-
- You should have received a copy of the GNU Library General Public
- License along with this library; if not, write to the
- Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
-*/
+  Copyright (C) 2001-2004 Taku Kudo <taku-ku@is.aist-nara.ac.jp>
+  This is free software with ABSOLUTELY NO WARRANTY.
+  
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Lesser General Public
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
+  
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Lesser General Public License for more details.
+  
+  You should have received a copy of the GNU Lesser General Public
+  License along with this library; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*/  
 #include "viterbi.h"
 
 namespace MeCab {
 
 #ifdef _VITERBI_WITH_ALL_PATH
-   void Viterbi::connectWithAllPath
+   bool Viterbi::connectWithAllPath
 #else
-   void Viterbi::connectNormal
+   bool Viterbi::connectNormal
 #endif
      (unsigned int pos, Node *rNode)
   {
@@ -41,12 +40,12 @@ namespace MeCab {
       for (Node *lNode = endNodeList[pos]; lNode; lNode = lNode->lnext) {
 
 	register unsigned int cost = lNode->cost + tokenizer->getCost (lNode->prev, lNode, rNode);
-
+	 
 	if (cost < bestCost) {
 	  bestNode  = lNode;
 	  bestCost  = cost;
 	}
-
+	 
 #ifdef _VITERBI_WITH_ALL_PATH
 	Path *path = pathFreeList->alloc ();
 	path->cost = cost;
@@ -55,6 +54,12 @@ namespace MeCab {
 	rNode->path = path;
 #endif
       }
+       
+      // overflow check 2003/03/09 
+      if (! bestNode) {
+	 _what = "Viterbi::connect(): too long sentence.";
+         return false;
+      }
 
       rNode->prev    = bestNode;
       rNode->next    = 0;
@@ -68,7 +73,7 @@ namespace MeCab {
 	if (begin + pos2 == end) continue;
 	Node *rNode2 = lookup (pos2);
 	for (; rNode2; rNode2 = rNode2->rnext) {
-	  rNode2->cost   = rNode->cost + tokenizer->getCost (rNode->prev, rNode, rNode2);
+	   rNode2->cost   = rNode->cost + tokenizer->getCost (rNode->prev, rNode, rNode2);
 
 #ifdef _VITERBI_WITH_ALL_PATH
 	  Path *path = pathFreeList->alloc ();
@@ -85,5 +90,7 @@ namespace MeCab {
 	}
       } 
     }
+     
+    return true; 
   }
 }
